# Africa Macroeconomic Monitor Database API

A python API providing access to a relational database with macroeconomic data for Africa.
The database contains >700 macroeconomic time series from mostly international sources,
grouped into 50 macroeconomic and development-related topics. Series are carefully selected
on the basis of data coverage for Africa and relevance to the macro-development context.
The project is part of the [Kiel Institute Africa Initiative](https://www.ifw-kiel.de/institute/initiatives/kiel-institute-africa-initiative/),
which, amongst other things, aims to develop a parsimonious database with highly relevant indicators
to monitor macroeconomic developments in Africa, accessible through a fast API and a web-based platform
at https://africamonitor.ifw-kiel.de/.
